@@ -1,7 +1,7 @@
 # ABSTRACT: Utilities for Monitoring ElasticSearch
 package App::ElasticSearch::Utilities;
 
-our $VERSION = '2.5'; # VERSION
+our $VERSION = '2.6'; # VERSION
 
 use strict;
 use warnings;
@@ -50,6 +50,7 @@ use Sub::Exporter -setup => {
         index   => [qw(:default es_index_valid es_index_fields es_index_days_old es_index_shard_replicas)],
     },
 };
+use App::ElasticSearch::Utilities::VersionHacks qw(_fix_version_request);
 
 
 my %opt = ();
@@ -134,6 +135,8 @@ foreach my $literal ( keys %PATTERN_REGEX ) {
     $PATTERN =~ s/\Q$literal\E/$PATTERN_REGEX{$literal}/g;
 }
 
+our $CURRENT_VERSION;
+
 
 my %_pattern=(
     re     => $PATTERN,
@@ -143,6 +146,24 @@ sub es_pattern {
     return wantarray ? %_pattern : \%_pattern;
 }
 
+sub _get_es_version {
+    return $CURRENT_VERSION if defined $CURRENT_VERSION;
+    eval {
+        my ($status,$result) = Elastijk::request({
+            host    => $DEF{HOST},
+            port    => $DEF{PORT},
+            method  => 'GET',
+            command => '/',
+        });
+        if( $status eq "200" ) {
+            $CURRENT_VERSION = join('.', (split /\./,$result->{version}{number})[0,1]);
+        }
+    };
+    $CURRENT_VERSION ||= 0;
+    debug({color=>'magenta'}, "FOUND VERISON '$CURRENT_VERSION'");
+    return $CURRENT_VERSION;
+};
+
 
 my $ES = undef;
 
@@ -180,7 +201,10 @@ sub es_connect {
 
 sub es_request {
     my $instance = ref $_[0] eq 'Elastijk::oo' ? shift @_ : es_connect();
-    my($url,$options,$body) = @_;
+
+    $CURRENT_VERSION = _get_es_version() if !defined $CURRENT_VERSION;
+
+    my($url,$options,$body) = _fix_version_request(@_);
 
     # Pull connection options
     $options->{$_} = $instance->{$_} for qw(host port);
@@ -369,8 +393,10 @@ sub es_index_shards {
     my %shards = map { $_ => 0 } qw(primaries replicas);
     my $result = es_request('_settings', {index=>$index});
     if( defined $result && ref $result eq 'HASH')  {
-        $shards{primaries} = $result->{$index}{settings}{'index.number_of_shards'};
-        $shards{replicas}  = $result->{$index}{settings}{'index.number_of_replicas'};
+        $shards{primaries} = $CURRENT_VERSION < 1.0 ? $result->{$index}{settings}{'index.number_of_shards'}
+                                                    : $result->{$index}{settings}{index}{number_of_shards};
+        $shards{replicas}  = $CURRENT_VERSION < 1.0 ? $result->{$index}{settings}{'index.number_of_replicas'}
+                                                    : $result->{$index}{settings}{index}{number_of_replicas};
     }
 
     return wantarray ? %shards : \%shards;
@@ -496,7 +522,7 @@ sub es_node_stats {
     push @cmd, join(',', @nodes) if @nodes;
     push @cmd, 'stats';
 
-    return es_request(join('/',@cmd), { uri_param => {all => 'true'} });
+    return es_request(join('/',@cmd), { uri_param => {all => 'true', human => 'true'} });
 }
 
 
@@ -532,13 +558,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::ElasticSearch::Utilities - Utilities for Monitoring ElasticSearch
 
 =head1 VERSION
 
-version 2.5
+version 2.6
 
 =head1 SYNOPSIS
 
