@@ -171,13 +171,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 es-daily-index-maintenance.pl - Run to prune old indexes and optimize existing
 
 =head1 VERSION
 
-version 2.5
+version 2.6
 
 =head1 SYNOPSIS
 
@@ -195,6 +197,31 @@ Options:
     --replicas          Run the replic aging hook
     --replicas-age      Age of the index to reach the minimum replicas (default:60)
     --replicas-min      Minimum number of replicas this index may have (default:0)
+    --replicas-max      Maximum number of replicas this index may have (default:100)
+
+From App::ElasticSearch::Utilities:
+
+    --local         Use localhost as the elasticsearch host
+    --host          ElasticSearch host to connect to
+    --port          HTTP port for your cluster
+    --noop          Any operations other than GET are disabled
+    --timeout       Timeout to ElasticSearch, default 30
+    --keep-proxy    Do not remove any proxy settings from %ENV
+    --index         Index to run commands against
+    --base          For daily indexes, reference only those starting with "logstash"
+                     (same as --pattern logstash-* or logstash-DATE)
+    --datesep       Date separator, default '.' also (--date-separator)
+    --pattern       Use a pattern to operate on the indexes
+    --days          If using a pattern or base, how many days back to go, default: all
+
+=head2 ARGUMENT GLOBALS
+
+Some options may be specified in the B</etc/es-utils.yaml> or B<$HOME/.es-utils.yaml> file:
+
+    ---
+    host: esproxy.example.com
+    port: 80
+    timeout: 10
 
 From CLI::Helpers:
 
@@ -246,6 +273,12 @@ The minimum number of replicas to allow replica aging to set.  The default is 0
 
     --replicas-min=1
 
+=item B<replicas-max>
+
+The maximum number of replicas to allow replica aging to set.  The default is 100
+
+    --replicas-max=2
+
 =back
 
 =head1 AUTHOR
