@@ -24,7 +24,7 @@ GetOptions(\%OPT,
 pod2usage(1) if $OPT{help};
 pod2usage(-exitval => 0, -verbose => 2) if $OPT{manual};
 
-my $cres = es_request('_cluster/state');
+my $cres = es_request('_cluster/health');
 my $CLUSTER = defined $cres ? $cres->{cluster_name} : 'UNKNOWN';
 
 output({clear=>1,color=>'magenta'}, "Cluster [$CLUSTER] contains $cres->{number_of_nodes} nodes.", '-='x20);
@@ -62,13 +62,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 es-nodes.pl - Listing the nodes in a cluster with some details
 
 =head1 VERSION
 
-version 2.5
+version 2.6
 
 =head1 SYNOPSIS
 
@@ -80,6 +82,30 @@ Options:
     --manual            print full manual
     --attibutes         Comma separated list of attributes to display, default is NONE
 
+From App::ElasticSearch::Utilities:
+
+    --local         Use localhost as the elasticsearch host
+    --host          ElasticSearch host to connect to
+    --port          HTTP port for your cluster
+    --noop          Any operations other than GET are disabled
+    --timeout       Timeout to ElasticSearch, default 30
+    --keep-proxy    Do not remove any proxy settings from %ENV
+    --index         Index to run commands against
+    --base          For daily indexes, reference only those starting with "logstash"
+                     (same as --pattern logstash-* or logstash-DATE)
+    --datesep       Date separator, default '.' also (--date-separator)
+    --pattern       Use a pattern to operate on the indexes
+    --days          If using a pattern or base, how many days back to go, default: all
+
+=head2 ARGUMENT GLOBALS
+
+Some options may be specified in the B</etc/es-utils.yaml> or B<$HOME/.es-utils.yaml> file:
+
+    ---
+    host: esproxy.example.com
+    port: 80
+    timeout: 10
+
 From CLI::Helpers:
 
     --color             Boolean, enable/disable color, default use git settings
